Clojure wrapper for the Google Sheets API (v4).
Provides idiomatic Clojure functions for reading, writing, and managing Google Sheets spreadsheets.
Auth: use csl/scoped-delegated-credentials or csl/user-credentials with the appropriate scope:
Values functions accept and return plain Clojure vectors-of-vectors. Enum options (e.g. :value-input-option) accept kebab-case keywords that are coerced internally (:user-entered -> "USER_ENTERED").
All functions return {:data ...} on success or {:error ...} on failure.
Clojure wrapper for the Google Sheets API (v4).
Provides idiomatic Clojure functions for reading, writing, and managing
Google Sheets spreadsheets.
Auth: use csl/scoped-delegated-credentials or csl/user-credentials with
the appropriate scope:
- SheetsScopes/SPREADSHEETS (read + write)
- SheetsScopes/SPREADSHEETS_READONLY (read-only access)
Values functions accept and return plain Clojure vectors-of-vectors.
Enum options (e.g. :value-input-option) accept kebab-case keywords
that are coerced internally (:user-entered -> "USER_ENTERED").
All functions return {:data ...} on success or {:error ...} on failure.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |